@@ -37,7 +37,7 @@ class MessagesModel : public QAbstractListModel
     Q_PROPERTY(bool shouldStartOpened READ shouldStartOpened CONSTANT)
 
   public:
-    MessagesModel(const Tp::AccountPtr &account, QObject *parent = 0);
+    MessagesModel(const Tp::AccountPtr &account, QObject *parent = nullptr);
     ~MessagesModel() override;
 
     enum Roles {
@@ -77,6 +77,11 @@ class MessagesModel : public QAbstractListModel
     Tp::AccountPtr account() const;
     void setAccount(const Tp::AccountPtr &account);
 
+    /**
+     * Useful for offline history retrieving (as there's no text channel when offline)
+     */
+    void setContactData(const QString &contactId, const QString &contactAlias);
+
     bool isVisibleToUser() const;
     void setVisibleToUser(bool visible);
 
@@ -88,12 +93,14 @@ class MessagesModel : public QAbstractListModel
     QString lastMessage() const;
     QDateTime lastMessageDateTime() const;
 
+
   Q_SIGNALS:
     void visibleToUserChanged(bool visible);
     void unreadCountChanged(int unreadMesssagesCount);
     void lastMessageChanged();
 
   public Q_SLOTS:
+    void fetchMoreHistory();
     void sendNewMessage(const QString &message);
 
   private Q_SLOTS:
