@@ -48,7 +48,7 @@ class KTPCOMMONINTERNALS_EXPORT PendingLoggerDates : public KTp::PendingLoggerOp
     /**
      * Destructor.
      */
-    virtual ~PendingLoggerDates();
+    ~PendingLoggerDates() override;
 
     /**
      * Returns account for which the dates are queried.
@@ -69,7 +69,7 @@ class KTPCOMMONINTERNALS_EXPORT PendingLoggerDates : public KTp::PendingLoggerOp
   protected:
     explicit PendingLoggerDates(const Tp::AccountPtr &account,
                                 const KTp::LogEntity &entity,
-                                QObject *parent = 0);
+                                QObject *parent = nullptr);
 
     void setDates(const QList<QDate> &dates);
 
