@@ -49,7 +49,6 @@ MainWindow::MainWindow(QWidget *parent)
     saveLogAction->setToolTip(i18nc("Toolbar icon tooltip", "Save log of the current tab"));
     toolBar()->addAction(saveLogAction);
 
-    connect(m_ui.mcLogsView, SIGNAL(statusMessage(QString)), statusBar(), SLOT(showMessage(QString)));
     connect(saveLogAction, SIGNAL(triggered(bool)), this, SLOT(saveLogFile()));
 }
 
@@ -84,8 +83,8 @@ void MainWindow::onAccountManagerBecameReady(Tp::PendingOperation* op)
 
 void MainWindow::initConnectionManagerTabs(const QSet<QString>& connectionManagerSet)
 {
-    QStringList connectionManagerStringList = connectionManagerSet.toList();
-    qSort(connectionManagerStringList);
+    QStringList connectionManagerStringList = connectionManagerSet.values();
+    std::sort(connectionManagerStringList.begin(), connectionManagerStringList.end());
 
     Q_FOREACH(QString connectionManager, connectionManagerStringList) {
         QWidget *cmTab = new QWidget();
